<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:fo="http://www.w3.org/1999/XSL/Format" 
    version="1.0">
    
    <!--
        Image size fix
        
        1. If outputclass attr = 'scale', scale the image.
        2. Otherwise if the attr's don't have a dimension (in, pt, ect.), then scale to Windows 96dpi
        
        This has only been tested with RenderX
        See "Scaling images using scale-to-fit" (http://renderx.com/usecasestest.html)
    -->
    
    <xsl:template name="placeImage">
        <xsl:param name="imageAlign"/>
        <xsl:param name="href"/>
        <xsl:param name="height"/>
        <xsl:param name="width"/>
        
        <xsl:variable name="scale" select="string(@scale)"/>
        <!--Using align attribute set according to image @align attribute-->
        <xsl:call-template name="processAttrSetReflection">
            <xsl:with-param name="attrSet" select="concat('__align__', $imageAlign)"/>
            <xsl:with-param name="path" select="'../attrs/xm-cfg/commons-attr.xsl'"/>
        </xsl:call-template>
        <xsl:choose>
            <xsl:when test="@outputclass='scale'"><!-- scale the image -->
                <fo:block line-height="1pt">
                    <fo:external-graphic src="url({$href})" content-width="scale-to-fit" content-height="100%" width="100%" scaling="uniform" />
                </fo:block>
            </xsl:when>
            <xsl:otherwise>
                <fo:external-graphic src="url({$href})" xsl:use-attribute-sets="image">
                    <!--Setting image height if defined-->
                    <!--xsl:message>[HIT!] fo:external-graphic $width="<xsl:value-of select="$width"/>" $height="<xsl:value-of select="$height"/>" $scale="<xsl:value-of select="$scale"/>"</xsl:message-->
                    <xsl:choose>
                        <xsl:when test="string($height) and not(string($width))">
                            <xsl:attribute name="content-height">
                                <xsl:choose>
                                    <xsl:when test="not(string(number($height)) = 'NaN')">
                                        <xsl:value-of select="concat($height div 72,'in')"/>
                                    </xsl:when>
                                    <xsl:when test="$height">
                                        <xsl:value-of select="$height"/>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:attribute>
                            <xsl:attribute name="scaling">uniform</xsl:attribute>
                        </xsl:when>
                        <!--Setting image width if defined-->
                        <xsl:when test="string($width) and not(string($height))">
                            <xsl:attribute name="content-width">
                                <xsl:choose>
                                    <xsl:when test="not(string(number($width)) = 'NaN')">
                                        <xsl:value-of select="concat($width div 72,'in')"/>
                                    </xsl:when>
                                    <xsl:when test="$width">
                                        <xsl:value-of select="$width"/>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:attribute>
                            <xsl:attribute name="scaling">uniform</xsl:attribute>
                        </xsl:when>
                        <xsl:when test="string($width) and string($height)">
                            <xsl:attribute name="content-height">
                                <xsl:choose>
                                    <xsl:when test="not(string(number($height)) = 'NaN')">
                                        <xsl:value-of select="concat($height div 72,'in')"/>
                                    </xsl:when>
                                    <xsl:when test="$height">
                                        <xsl:value-of select="$height"/>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:attribute>
                            <xsl:attribute name="content-width">
                                <xsl:choose>
                                    <xsl:when test="not(string(number($width)) = 'NaN')">
                                        <xsl:value-of select="concat($width div 72,'in')"/>
                                    </xsl:when>
                                    <xsl:when test="$width">
                                        <xsl:value-of select="$width"/>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:attribute>
                            <xsl:attribute name="scaling">non-uniform</xsl:attribute>
                        </xsl:when>
                        <xsl:when test="string($scale)">
                            <xsl:attribute name="scaling">uniform</xsl:attribute>
                            <xsl:attribute name="content-width">
                                <xsl:value-of select="concat(normalize-space($scale),'%')"/>
                            </xsl:attribute>
                        </xsl:when>
                    </xsl:choose>
                </fo:external-graphic>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
</xsl:stylesheet>
